@@ -22,13 +22,18 @@ class HeaterGraph(Gtk.DrawingArea):
         self.connect('draw', self.draw_graph)
         self.add_events(Gdk.EventMask.TOUCH_MASK)
         self.add_events(Gdk.EventMask.BUTTON_PRESS_MASK)
-        self.connect('button_press_event', screen.reset_screensaver_timeout)
+        self.connect('button_press_event', screen.screensaver.reset_timeout)
         self.connect('button_press_event', self.event_cb)
         self.font_size = round(font_size * 0.75)
         self.fullscreen = fullscreen
         if fullscreen:
             GLib.timeout_add_seconds(1, self.update_graph)
         self.fs_graph = None
+        self.max_temp = 0
+        for section in self.printer.config:
+            if "max_temp" in self.printer.get_config_section(section):
+                self.max_temp = max(float(self.printer.get_config_section(section)["max_temp"]), self.max_temp)
+        self.max_temp = min(self.max_temp, 999)
 
     def update_graph(self):
         self.queue_draw()
@@ -64,10 +69,12 @@ class HeaterGraph(Gtk.DrawingArea):
         mnum = [0]
         for device in self.store:
             if self.store[device]['show']:
-                if temp := self.printer.get_temp_store(device, "temperatures", data_points):
-                    mnum.append(max(temp))
-                if target := self.printer.get_temp_store(device, "targets", data_points):
-                    mnum.append(max(target))
+                temp = self.printer.get_temp_store(device, "temperatures", data_points)
+                if isinstance(temp, list):
+                    mnum.append(max([v for v in temp if v is not None]))
+                target = self.printer.get_temp_store(device, "targets", data_points)
+                if isinstance(target, list):
+                    mnum.append(max([v for v in target if v is not None]))
         return max(mnum)
 
     def draw_graph(self, da: Gtk.DrawingArea, ctx: cairoContext):
@@ -122,8 +129,16 @@ class HeaterGraph(Gtk.DrawingArea):
             ctx.set_dash([1, 0])
         d_len = len(data) - 1
 
+        start_x = gsize[1][0]
+        end_x = gsize[0][0]
+
         for i, d in enumerate(data):
+            if d is None:
+                continue
+
             p_x = i * swidth + gsize[0][0] if i != d_len else gsize[1][0] - 1
+            start_x = min(start_x, p_x)
+            end_x = max(end_x, p_x)
             if dashed:  # d between 0 and 1
                 p_y = gsize[1][1] - (d * (gsize[1][1] - gsize[0][1]))
             else:
@@ -133,15 +148,15 @@ class HeaterGraph(Gtk.DrawingArea):
             ctx.line_to(p_x, p_y)
         if fill:
             ctx.stroke_preserve()
-            ctx.line_to(gsize[1][0] - 1, gsize[1][1] - 1)
-            ctx.line_to(gsize[0][0] + 1, gsize[1][1] - 1)
+            ctx.line_to(end_x - 1, gsize[1][1] - 1)
+            ctx.line_to(start_x + 1, gsize[1][1] - 1)
             ctx.fill()
         else:
             ctx.stroke()
 
     def graph_lines(self, ctx: cairoContext, gsize, max_num):
         nscale = 10
-        max_num = min(max_num, 999)
+        max_num = min(max_num, self.max_temp)
         while (max_num / nscale) > 5:
             nscale += 10
         r = int(max_num / nscale) + 1
