@@ -1,6 +1,7 @@
+import logging
 import os.path
 import pathlib
-import logging
+
 import gi
 
 gi.require_version("Gtk", "3.0")
@@ -335,6 +336,8 @@ class Panel(ScreenPanel):
             result = f'<big><b>{spool.name}</b></big>\n'
         else:
             result = f'<big>{spool.name}</big>\n'
+        if hasattr(spool, "comment"):
+            result += f'{_("Comment")}:<b> {spool.comment}</b>\n'
         if spool.last_used:
             result += f'{_("Last used")}:<b> {spool.last_used.astimezone():{self.timeFormat}}</b>\n'
         if hasattr(spool, "remaining_weight"):
