@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 XDG_RUNTIME_DIR=/run/user/$(id -u)
 export XDG_RUNTIME_DIR
@@ -13,9 +13,9 @@ fi
 
 if [[ "$BACKEND" =~ ^[wW]$ ]]; then
     echo "Running KlipperScreen on Cage"
-    /usr/bin/cage -ds $KS_XCLIENT
+    exec /usr/bin/cage -ds $KS_XCLIENT
 
 else
     echo "Running KlipperScreen on X in display :0 by default"
-    /usr/bin/xinit $KS_XCLIENT
+    exec /usr/bin/xinit $KS_XCLIENT
 fi
